"""Tests for util.whatdateformat."""

import unittest
from whatformat.util.whatdateformat import get_unique_format_strings


class WhatDateFormatTests(unittest.TestCase):
    """Tests for util.whatdateformat."""

    def test_get_unique_format_strings(self):
        """Test for util.whatdateformat.get_unique_format_strings()."""
        cases = [
            ('Jan 2', ['%b %-d']),
            ('Jan 15', ['%b %d']),
            ('1-2-1999', ['%-m-%-d-%Y']),
            ('1.2.1999', ['%-m.%-d.%Y']),
            ('1.2.1999.', ['%-m.%-d.%Y.']),
            ('1/2/1999', ['%-m/%-d/%Y']),
            ('1999.1.2', ['%Y.%-m.%-d']),
            ('1999-1-2', ['%Y-%-m-%-d']),
            ('1999. 2. 1', ['%Y. %-m. %-d']),
            ('1999.2.1', ['%Y.%-m.%-d']),
            ('1999/2/1', ['%Y/%-m/%-d']),
            ('28-11-1999', ['%d-%m-%Y']),
            ('28.11.1999', ['%d.%m.%Y']),
            ('28.11.1999.', ['%d.%m.%Y.']),
            ('28/11/1999', ['%d/%m/%Y']),
            ('11.28.1999', ['%m.%d.%Y']),
            ('11/28/1999', ['%m/%d/%Y']),
            ('11-28-1999', ['%m-%d-%Y']),
            ('1-28-1999', ['%-m-%d-%Y']),
            ('1.28.1999', ['%-m.%d.%Y']),
            ('1.28.1999.', ['%-m.%d.%Y.']),
            ('1/28/1999', ['%-m/%d/%Y']),
            ('11-28-1999', ['%m-%d-%Y']),
            ('11/28/1999', ['%m/%d/%Y']),
            ('1999-11-28', ['%Y-%m-%d']),
            ('1999.11.28.', ['%Y.%m.%d.']),
            ('1999/11/28', ['%Y/%m/%d']),
            ('ayy lmao', []),
            ('', []),
        ]
        for (date, formats) in cases:
            self.assertEqual(set(get_unique_format_strings(date)),
                             set(formats))
